@@ -1,4 +1,4 @@
-package Pcore::API::PayPal v0.1.0;
+package Pcore::API::PayPal v0.1.1;
 
 use Pcore -dist, -class, -result, -const;
 use Pcore::Util::Data qw[from_json to_json to_b64];
@@ -59,7 +59,9 @@ sub create_payment ( $self, $payment, $cb ) {
                     my $api_res;
 
                     if ( !$res ) {
-                        $api_res = result [ $res->status, $res->reason ];
+                        my $data = $res->body ? from_json $res->body : {};
+
+                        $api_res = result [ $res->status, $data->{message} // $res->reason ];
                     }
                     else {
                         my $data = from_json $res->body;
@@ -86,7 +88,7 @@ sub create_payment ( $self, $payment, $cb ) {
 }
 
 # https://developer.paypal.com/docs/api/payments/#payment_execute
-sub exec_payment ( $self, $payment_id, $data, $cb ) {
+sub exec_payment ( $self, $payment_id, $payer_id, $cb ) {
     $self->_get_access_token(
         sub ($access_token) {
             my $url = ( $self->{sandbox} ? $SANDBOX_ENDPOINT : $LIVE_ENDPOINT ) . "/v1/payments/payment/$payment_id/execute";
@@ -98,12 +100,14 @@ sub exec_payment ( $self, $payment_id, $data, $cb ) {
                     ACCCEPT       => 'application/json',
                     AUTHORIZATION => "$access_token->{token_type} $access_token->{access_token}",
                 },
-                body => to_json( $data // {} ),
+                body      => to_json( { payer_id => $payer_id } ),
                 on_finish => sub ($res) {
                     my $api_res;
 
                     if ( !$res ) {
-                        $api_res = result [ $res->status, $res->reason ];
+                        my $data = $res->body ? from_json $res->body : {};
+
+                        $api_res = result [ $res->status, $data->{message} // $res->reason ];
                     }
                     else {
                         my $data = from_json $res->body;
@@ -130,6 +134,16 @@ sub exec_payment ( $self, $payment_id, $data, $cb ) {
 }
 
 1;
+## -----SOURCE FILTER LOG BEGIN-----
+##
+## PerlCritic profile "pcore-script" policy violations:
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+## | Sev. | Lines                | Policy                                                                                                         |
+## |======+======================+================================================================================================================|
+## |    3 | 91                   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
+##
+## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
